---
name: "\U0001F680 Feature request"
about: "I have a suggestion (and may want to implement it \U0001F642)!"
title: ""
labels: "i: enhancement"
assignees: J535D165
---

## Feature Request

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I have an issue when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen. Add any considered drawbacks.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Teachability, Documentation, Adoption, Migration Strategy**
A clear explanation of how your new feature can be used by users.
Maybe with screenshot or design?
